import Auth from '@/views/layout/auth'
import { router, rootRouter } from './routes-common'

type metaType = {
  isRegister: boolean
}

// 不需要登录的路由
// companion-teacher-register
const noLoginRouter = [
  {
    path: '/companion-teacher-register',
    name: 'companion-teacher-register',
    component: () => import('@/school/companion-teacher/companion-teacher-register'),
    meta: {
      title: '乐团伴学指导注册'
    }
  },
  {
    path: '/manage-teacher-register',
    name: 'manage-teacher-register',
    component: () => import('@/school/manage-teacher/manage-teacher-register'),
    meta: {
      title: '乐团管理老师注册'
    }
  }
]

export default [
  {
    path: '/',
    component: Auth,
    children: [
      ...router,
      {
        path: '/login',
        name: 'login',
        component: () => import('@/views/layout/login'),
        meta: {
          isRegister: false
        } as metaType
      },
      {
        path: '/home',
        name: 'home',
        component: () => import('@/school/home/index')
      },
      {
        path: '/my-orchestra',
        name: 'my-orchestra',
        component: () => import('@/school/orchestra/index'),
        meta: {
          title: '我的乐团'
        }
      },
      {
        path: '/create-orchestra',
        name: 'create-orchestra',
        component: () => import('@/school/orchestra/create-orchestra/index'),
        meta: {
          title: '新建乐团'
        }
      },
      {
        path: '/create-orchestra-teacher',
        name: 'create-orchestra-teacher',
        component: () => import('@/school/orchestra/create-orchestra/select-teacher'),
        meta: {
          title: '选择老师'
        }
      },
      {
        path: '/orchestra-detail',
        name: 'orchestra-detail',
        component: () => import('@/school/orchestra/orchestra-detail'),
        meta: {
          title: '乐团详情'
        }
      },
      {
        path: '/school-photo',
        name: 'school-photo',
        component: () => import('@/school/orchestra/compontent/photo'),
        meta: {
          title: '乐团相册'
        }
      },
      {
        path: '/photo-detail',
        name: 'photo-detail',
        component: () => import('@/school/orchestra/compontent/photo-detail'),
        meta: {
          title: '相册详情'
        }
      },
      {
        path: '/mass-message',
        name: 'mass-message',
        component: () => import('@/school/mass-message/index'),
        meta: {
          title: '群发记录'
        }
      },
      {
        path: '/create-message',
        name: 'create-message',
        component: () => import('@/school/mass-message/create-message'),
        meta: {
          title: '群发消息'
        }
      },
      {
        path: '/companion-teacher',
        name: 'companion-teacher',
        component: () => import('@/school/companion-teacher/index'),
        meta: {
          title: '伴学指导'
        }
      },
      {
        path: '/companion-teacher-detail',
        name: 'companion-teacher-detail',
        component: () => import('@/school/companion-teacher/companion-detail'),
        meta: {
          title: '伴学指导详情'
        }
      },
      {
        path: '/companion-unbind',
        name: 'companion-unbind',
        component: () => import('@/school/companion-teacher/unbind'),
        meta: {
          title: '课程交接'
        }
      },
      {
        path: '/manage-teacher',
        name: 'manage-teacher',
        component: () => import('@/school/manage-teacher/index'),
        meta: {
          title: '管理老师'
        }
      },
      {
        path: '/manage-teacher-detail',
        name: 'manage-teacher-detail',
        component: () => import('@/school/manage-teacher/manage-detail'),
        meta: {
          title: '管理老师详情'
        }
      },
      {
        path: '/save-share-image',
        name: 'save-share-image',
        component: () => import('@/school/save-share-image/index'),
        meta: {
          title: '注册'
        }
      },
      {
        path: '/orchestra-information',
        name: 'orchestra-information',
        component: () => import('@/school/orchestra/orchestra-information'),
        meta: {
          title: '乐团资讯'
        }
      },
      {
        path: '/add-information',
        name: 'add-information',
        component: () => import('@/school/orchestra/modal/add-information'),
        meta: {
          title: '添加资讯'
        }
      },
      {
        path: '/exercise-record',
        name: 'exercise-record',
        component: () => import('@/views/exercise-record'),
        meta: {
          title: '练习记录'
        }
      },
      {
        path: '/exercis-detail',
        name: 'exercis-detail',
        component: () => import('@/views/exercise-record/exercis-detail'),
        meta: {
          title: '练习统计'
        }
      },
      {
        path: '/attendance',
        name: 'attendance',
        component: () => import('@/school/attendance/index'),
        meta: {
          title: '考勤管理'
        }
      },
      {
        path: '/student-att-day',
        name: 'student-att-day',
        component: () => import('@/school/attendance/student-att-day'),
        meta: {
          title: '考勤详情'
        }
      },
      {
        path: '/teacher-attendDetail',
        name: 'teacher-attendDetail',
        component: () => import('@/school/attendance/components/teacher-attendDetail'),
        meta: {
          title: '考勤详情'
        }
      },
      //
      {
        path: '/ranking-list',
        name: 'ranking-list',
        component: () => import('@/school/ranking-list/index'),
        meta: {
          title: '排行榜'
        }
      },
      {
        path: '/approval-manage',
        name: 'approval-manage',
        component: () => import('@/school/approval-manage/index'),
        meta: {
          title: '待办事项'
        }
      },
      {
        path: '/student-leave',
        name: 'student-leave',
        component: () => import('@/school/approval-manage/components/student-leave'),
        meta: {
          title: '审批详情'
        }
      },
      {
        path: '/train-planning',
        name: 'train-planning',
        component: () => import('@/school/train-planning/index'),
        meta: {
          title: '乐团排课'
        }
      },
      {
        path: '/train-content',
        name: 'train-content',
        component: () => import('@/school/train-planning/component/train-content'),
        meta: {
          title: '训练内容'
        }
      },
      {
        path: '/practice-detail',
        name: 'practice-detail',
        component: () => import('@/school/train-planning/component/practice-detail'),
        meta: {
          title: '训练详情'
        }
      },
      {
        path: '/course-preview',
        name: 'course-preview',
        component: () => import('@/school/train-planning/component/course-preview'),
        meta: {
          title: '课程预览'
        }
      },
      {
        path: '/course-adjust',
        name: 'course-adjust',
        component: () => import('@/school/approval-manage/course-adjust'),
        meta: {
          title: '课程调整'
        }
      },
      {
        path: '/batch-adjust',
        name: 'batch-adjust',
        component: () => import('@/school/approval-manage/batch-adjust'),
        meta: {
          title: '批量调整'
        }
      },
      {
        path: '/school-detail',
        name: 'school-detail',
        component: () => import('@/school/school-detail/index'),
        meta: {
          title: '学校信息'
        }
      },
      {
        path: '/school-eidt',
        name: 'school-eidt',
        component: () => import('@/school/school-detail/eidt-school'),
        meta: {
          title: '修改学校地址'
        }
      },
      {
        path: '/attendance-rule',
        name: 'attendance-rule',
        component: () => import('@/views/attendance-rule/index'),
        meta: {
          title: '考勤规则'
        }
      },
      {
        path: '/orchestra-story',
        name: 'orchestra-story',
        component: () => import('@/school/orchestra-story/index'),
        meta: {
          title: '乐团事迹'
        }
      },
      {
        path: '/story-operation',
        name: 'story-operation',
        component: () => import('@/school/orchestra-story/story-operation/index'),
        meta: {
          title: '添加事迹'
        }
      },
      {
        path: '/subsidy-exercise-detail',
        name: 'subsidy-exercise-detail',
        component: () => import('@/school/approval-manage/subsidy/exercise-detail'),
        meta: {
          title: '训练补助详情'
        }
      },
      {
        path: '/subsidy-exercise-details',
        name: 'subsidy-exercise-details',
        component: () => import('@/school/approval-manage/subsidy/details'),
        meta: {
          title: '补助明细'
        }
      },
      {
        path: '/subsidy-grant-detail',
        name: 'subsidy-grant-detail',
        component: () => import('@/school/approval-manage/subsidy/grant-detail'),
        meta: {
          title: '管理补助详情'
        }
      },
      {
        path: '/subsidy-reward-detail',
        name: 'subsidy-reward-detail',
        component: () => import('@/school/approval-manage/subsidy/reward-detail'),
        meta: {
          title: '练习奖励详情'
        }
      },
      {
        path: '/unitDetail',
        name: 'unitDetail',
        component: () => import('@/views/unit-test/unit-list/unitDetail'),
        meta: {
          title: '测验详情'
        }
      },
      {
        path: '/unit-list',
        name: 'unit-list',
        component: () => import('@/views/unit-test/unit-list/index'),
        meta: {
          title: '阶段自测'
        }
      },
      {
        path: '/orchestra-photo-create',
        name: 'orchestra-photo-create',
        component: () => import('@/school/orchestra/compontent/photo-create'),
        meta: {
          title: '创建相册'
        }
      },
      {
        path: '/practice-rewards',
        name: 'practice-rewards',
        component: () => import('@/school/practice-rewards/index'),
        meta: {
          title: '练习奖励'
        }
      },
      {
        path: '/practice-rewards-detail',
        name: 'practice-rewards-detail',
        component: () => import('@/school/practice-rewards/detail'),
        meta: {
          title: '练习奖励详情'
        }
      },
      {
        path: '/attendance-rules',
        name: 'attendance-rules',
        component: () => import('@/school/attendance-rules'),
        meta: {
          title: '考勤规则设置'
        }
      },

      //
    ]
  },

  ...rootRouter,
  ...noLoginRouter
]
