/**管理老师管理补助表 */
interface ISchoolStaffManageSalary {
  /**预计的训练照片数 */
  expectPhotoNum: number | string
  /**扣减奖励 */
  reduceSalary: number | string
  /**补助标准 */
  standardSalary: number
  /**实际奖励 */
  actualSalary: number
  /**课件数 */
  coursewareNum: number | string
  /**预计奖励 */
  expectSalary: number | string
  /**训练照片数 */
  photoNum: number | string
}

/**老师课程表 */
interface ICourseSchedule {
  /**课程计划编号 */
  lessonCoursewareId: string
  /**训练规划类型: STANDARD：标准 PRACTISE：加练 ADJUST:调整 */
  arrangeType: 'STANDARD' | 'PRACTISE' | 'ADJUST'
  /**班级名 */
  className: string
  /**课程类型 */
  type:
  | 'PERCUSSION_SINGLE'
  | 'FLUTE_SINGLE'
  | 'SAX_SINGLE'
  | 'CLARINET_SINGLE'
  | 'TRUMPET_SINGLE'
  | 'TROMBONE_SINGLE'
  | 'HORN_SINGLE'
  | 'BARITONE_TUBA_SINGLE'
  | 'EUPHONIUM_SINGLE'
  | 'TUBA_SINGLE'
  | 'MUSIC_THEORY'
  | 'INSTRUMENTAL_ENSEMBLE'
  /**训练时长 */
  singleCourseTime: string | number
  /**班组IM群 */
  imGroupId: string
  /**乐团id */
  orchestraId: string
  /**学校编号 */
  schoolId: number | string
  /**是否必须配置课件 */
  coursewareFlag: boolean
  /**上课时间 */
  startTime: string
  /**课程id */
  id: string
  /**签退时间 */
  signOutTime: string
  /**课程老师签到信息 */
  attendanceStatus:
  | 'NORMAL'
  | 'EXCEPTION'
  | 'LATE'
  | 'EARLY'
  | 'TRUANCY'
  | 'NO_SIGN'
  | 'NO_SIGN_OUT'
  | 'LOCATION_EXCEPTION'
  /**伴学指导名 */
  teacherAvatar: string
  /**课程计划内容编号 */
  lessonCoursewareDetailId: string
  /**上课日期 */
  classDate: string
  /**伴学指导名 */
  teacherName: string
  /**学员考勤 */
  studentAttendance: 'LATE' | 'NORMAL' | 'LEAVE' | 'TRUANCY' | 'UNCALLED'
  /**时间冲突 */
  timeConflict: boolean
  /**乐团名 */
  orchestraName: string
  /**是否签退 */
  signOut: boolean
  /**签到时间 */
  signInTime: string
  /**伴学指导Id */
  teacherId: string
  /**是否签到 */
  signIn: boolean
  /**作业是否完成:NO_HOMEWORK：未布置作业 UNSUBMITTED：未提交 SUBMITTED：已提交 TARGET：已达标 */
  homeworkComplete: 'NO_HOMEWORK' | 'UNSUBMITTED' | 'SUBMITTED' | 'TARGET'
  /**冲突类型 */
  conflictType: Array<any> | string
  /**下课时间 */
  endTime: string
  /**班级id */
  classGroupId: string
  /**预计上课人数 */
  preStudentNum: string
  /**课程状态 NOT_START未开始 ING进行中 COMPLETE已完成 */
  status: 'NOT_START' | 'ING' | 'COMPLETE'
}

/**管理老师训练奖励表 */
interface ISchoolStaffTrainingSalary {
  /**一周结束日期 */
  endDate: string
  /**扣减明细 */
  deductionDetail: string
  /**老师编号 */
  userId: string
  /**奖励变动原因 */
  deductionReason: string
  /**扣减奖励 */
  reduceSalary: number
  /**奖励标准 */
  standardSalary: number
  /**实际奖励 */
  actualSalary: number
  /**结算时间 */
  settlementTime: string
  /**达标人数 */
  targetNum: number
  /**学校id */
  schoolId: string
  /**预计奖励 */
  expectSalary: number
  /**一周开始日期 */
  startDate: string
  /**结算状态 */
  status: 'WAIT' | 'SETTLED' | 'PART_SETTLED' | 'SETTLE_FAIL'
}

/**学员列表 */
interface IStudent {
  /**练习分钟 */
  practiceTimes: number
  /**昵称 */
  nickname: string
  /**头像 */
  avatar: string
  /**声部名， 多个逗号隔开 */
  subjectNames: string
  /**主键ID */
  userId: string
  /**声部ID */
  subjectId: string
}

/**补助详情数据明细-课程补助明细 */
interface ICourseSalaryRecordDetail {
  /**扣款金额 */
  reduceSalary: number
  /**补助详情列表数据 */
  courseSalaryRecordDetailList: ICourseSalaryRecordDetailItem[]
  /**实际补助金额 */
  actualSalary: number
  /**预计补助金额 */
  expectSalary: number
  /**老师名字 */
  userName: string
  /**老师头像 */
  avatar: string
}
/**课程补助详情数据集合 */
interface ICourseSalaryRecordDetailItem {
  /**课程类型 */
  courseType:
  | 'PERCUSSION_SINGLE'
  | 'FLUTE_SINGLE'
  | 'SAX_SINGLE'
  | 'CLARINET_SINGLE'
  | 'TRUMPET_SINGLE'
  | 'TROMBONE_SINGLE'
  | 'HORN_SINGLE'
  | 'BARITONE_TUBA_SINGLE'
  | 'EUPHONIUM_SINGLE'
  | 'TUBA_SINGLE'
  | 'TEST_CLARINET'
  | 'MUSIC_THEORY'
  | 'INSTRUMENTAL_ENSEMBLE'
  /**扣款金额 */
  reduceSalary: number
  /**补助标准 */
  standardSalary: number
  /**实际补助金额 */
  actualSalary: number
  /** 日期 */
  date: string
  /** 课程编号 */
  courseSalaryId: string
  /**天数 */
  days: number
  /**预计补助金额 */
  expectSalary: number
  /**课程考勤信息 */
  courseScheduleTeacherAttendanceList: ICourseScheduleTeacherAttendance[]
}
/**伴学指导签到 */
interface ICourseScheduleTeacherAttendance {
  /** 播放时长 */
  coursewarePlayTime: number
  /**建议学习时长 */
  adviseStudyTimeSecond: number
  /**上课时间 */
  times: string
  /**老师名称 */
  teacherName: string
  /**乐团名称 */
  orchestraName: string
  /**课程编号 */
  courseScheduleId: string
  scopeOfAttendance: number
  /**训练时长 */
  singleCourseTime: string
  /**签到状态（正常、异常、迟到、早退、旷课、未签到） */
  signInStatus:
  | 'NORMAL'
  | 'EXCEPTION'
  | 'LATE'
  | 'EARLY'
  | 'TRUANCY'
  | 'NO_SIGN'
  | 'NO_SIGN_OUT'
  | 'LOCATION_EXCEPTION'
  /**签到状态（正常、异常、迟到、早退、旷课、未签到）中文 */
  signInStatusTitle?: string,
  /** 签到金纬度状态 */
  signInLongitudeLatitudeStatus?:
  | 'NORMAL'
  | 'LOCATION_EXCEPTION'
  /**乐团编号 */
  orchestraId: string
  /**班级名称 */
  classGroupName: string
  /**签到时间 */
  signInTime: string
  /**是否为补助考勤 */
  subsidyFlag: boolean
  /**老师编号 */
  teacherId: string
  /**学校编号 */
  schoolId: string
  /**用户聊天ID */
  imUserId: string
  /**老师电话 */
  teacherPhone: string
  /**上课时间 */
  startTime: string
  /**班级im聊天 */
  classGroupImToken: string
  /**下课时间 */
  endTime: string
  /**考勤id */
  id: string
  /**签退状态（正常、异常、迟到、早退、旷课、未签到） */
  signOutStatus:
  | 'NORMAL'
  | 'EXCEPTION'
  | 'LATE'
  | 'EARLY'
  | 'TRUANCY'
  | 'NO_SIGN'
  | 'NO_SIGN_OUT'
  | 'LOCATION_EXCEPTION'
  /**签退状态（正常、异常、迟到、早退、旷课、未签到） */
  signOutStatusTitle?: string
  /** 签退经纬度状态 */
  signOutLongitudeLatitudeStatus?:
  | 'NORMAL'
  | 'LOCATION_EXCEPTION'
  /**签退时间 */
  signOutTime: string
  /**课程类型 */
  classType: 'SINGLE' | 'MUSIC_THEORY' | 'INSTRUMENTAL_ENSEMBLE'
  /**老师头像 */
  teacherAvatar: string
  /**班级编号 */
  classGroupId: string
  /**学校经纬度 */
  schoolLongitudeLatitude: string
  /**签退经纬度 */
  signOutLongitudeLatitude?: string
  /**签到经纬度 */
  signInLongitudeLatitude: string
}
