import { defineComponent, reactive } from 'vue'
import { Icon, Image } from 'vant'
import styles from './index.module.less'
import orchestraTopBg from '@/school/save-share-image/images/orchestra-top_bg.png'
import OQrcode from '@/components/o-qrcode'
import { browser } from '@/helpers/utils'
import { useRouter } from 'vue-router'
import OHeader from '@/components/o-header'
import OSticky from '@/components/o-sticky'
import { postMessage } from '@/helpers/native-message'

export default defineComponent({
  name: 'qrcode-payment',
  props: {
    url: {
      type: String,
      default: ''
    },
    pay_channel: {
      type: String,
      default: 'wx_pub'
    },
    orderType: {
      type: String,
      default: ''
    }
  },
  setup(props) {
    const router = useRouter()
    const state = reactive({
      height: 0
    })
    const onBack = () => {
      if (browser().isApp) {
        postMessage({ api: 'goBack' })
      } else {
        router.back()
      }
    }
    return () => (
      <div class={[styles.saveShareImage]}>
        {browser().isApp && (
          <OSticky
            position="top"
            onGetHeight={(height: any) => {
              state.height = height
              console.log(height, 'height')
            }}
          >
            <OHeader title={props.orderType === 'VIP' ? '会员购买' : '报名缴费'} />
          </OSticky>
        )}

        <Image src={orchestraTopBg} class={styles.topImage} style={{ top: state.height + 'px' }} />
        <div class={[styles.shareContaienr, styles.orchestraContainer]}>
          <div class={styles.schoolName}>{props.orderType === 'VIP' ? '会员购买' : '报名缴费'}</div>
          <div class={styles.shareType}>
            请截图下方二维码
            <span>登录{props.pay_channel === 'wx_pub' ? '微信' : '支付宝'}扫码支付</span>
          </div>

          <div class={styles.qrcodeSection}>
            <OQrcode text={props.url} logoSize={'small'} size={'100%'} />
          </div>

          <div class={styles.memo}>请在30分钟内扫码支付</div>
        </div>

        <div class={[styles.shareContaienr, styles.tips]}>
          <div class={styles.tipsTitle}>使用说明：</div>
          <div class={styles.tipsContent}>
            1.打开{props.pay_channel === 'wx_pub' ? '微信' : '支付宝'}扫一扫
            <br />
            2.选择相册中的二维码
            <br />
            3.请在30分钟内扫码支付
          </div>
        </div>
      </div>
    )
  }
})
